Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-03-01 11:00:54 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-03-01 11:01:53 +0300
commit7aed2de798b1e5f8663e8fe608a99f6c9f53c382 (patch)
tree1f811fd3d80e3cce969db7e317b5629e54cbe5ce /source/blender/editors/object
parent1fc5eb305a2bd61ed465db376cec73a3822c0bf6 (diff)
Cleanup: macro's w/ an _END need a matching _BEGIN
Convention from 2.7x, since some looping macros don't need an '_END', it avoids confusion to keep this.
Diffstat (limited to 'source/blender/editors/object')
-rw-r--r--source/blender/editors/object/object_add.c4
-rw-r--r--source/blender/editors/object/object_relations.c12
-rw-r--r--source/blender/editors/object/object_select.c2
-rw-r--r--source/blender/editors/object/object_vgroup.c2
4 files changed, 10 insertions, 10 deletions
diff --git a/source/blender/editors/object/object_add.c b/source/blender/editors/object/object_add.c
index c4bad6f76c9..cec79c8e4e8 100644
--- a/source/blender/editors/object/object_add.c
+++ b/source/blender/editors/object/object_add.c
@@ -1719,7 +1719,7 @@ static int convert_exec(bContext *C, wmOperator *op)
/* don't forget multiple users! */
{
- FOREACH_SCENE_OBJECT(scene, ob)
+ FOREACH_SCENE_OBJECT_BEGIN(scene, ob)
{
ob->flag &= ~OB_DONE;
@@ -2009,7 +2009,7 @@ static int convert_exec(bContext *C, wmOperator *op)
if (!keep_original) {
if (mballConverted) {
- FOREACH_SCENE_OBJECT(scene, ob_mball)
+ FOREACH_SCENE_OBJECT_BEGIN(scene, ob_mball)
{
if (ob_mball->type == OB_MBALL) {
if (ob_mball->flag & OB_DONE) {
diff --git a/source/blender/editors/object/object_select.c b/source/blender/editors/object/object_select.c
index c857a7be4a3..5cf04ddc735 100644
--- a/source/blender/editors/object/object_select.c
+++ b/source/blender/editors/object/object_select.c
@@ -159,7 +159,7 @@ void ED_object_base_activate(bContext *C, Base *base)
if (workspace->object_mode & OB_MODE_ALL_MODE_DATA) {
EvaluationContext eval_ctx;
CTX_data_eval_ctx(C, &eval_ctx);
- FOREACH_OBJECT(view_layer, ob) {
+ FOREACH_OBJECT_BEGIN(view_layer, ob) {
if (ob != obact) {
ED_object_mode_generic_exit(&eval_ctx, workspace, scene, ob);
}
diff --git a/source/blender/editors/object/object_vgroup.c b/source/blender/editors/object/object_vgroup.c
index 8c6ccb7e8f0..613af8e5259 100644
--- a/source/blender/editors/object/object_vgroup.c
+++ b/source/blender/editors/object/object_vgroup.c
@@ -3360,7 +3360,7 @@ static int vertex_group_copy_to_linked_exec(bContext *C, wmOperator *UNUSED(op))
Object *ob_active = ED_object_context(C);
int retval = OPERATOR_CANCELLED;
- FOREACH_SCENE_OBJECT(scene, ob_iter)
+ FOREACH_SCENE_OBJECT_BEGIN(scene, ob_iter)
{
if (ob_iter->type == ob_active->type) {
if (ob_iter != ob_active && ob_iter->data == ob_active->data) {
diff --git a/source/blender/editors/object/object_relations.c b/source/blender/editors/object/object_relations.c
index f2111adc09a..32753c91a04 100644
--- a/source/blender/editors/object/object_relations.c
+++ b/source/blender/editors/object/object_relations.c
@@ -1747,7 +1747,7 @@ static void single_object_users(Main *bmain, Scene *scene, View3D *v3d, const in
* button can be functional.*/
void ED_object_single_user(Main *bmain, Scene *scene, Object *ob)
{
- FOREACH_SCENE_OBJECT(scene, ob_iter)
+ FOREACH_SCENE_OBJECT_BEGIN(scene, ob_iter)
{
ob_iter->flag &= ~OB_DONE;
}
@@ -1791,7 +1791,7 @@ static void single_obdata_users(Main *bmain, Scene *scene, ViewLayer *view_layer
ID *id;
int a;
- FOREACH_OBJECT_FLAG(scene, view_layer, flag, ob)
+ FOREACH_OBJECT_FLAG_BEGIN(scene, view_layer, flag, ob)
{
if (!ID_IS_LINKED(ob)) {
id = ob->data;
@@ -1849,7 +1849,7 @@ static void single_obdata_users(Main *bmain, Scene *scene, ViewLayer *view_layer
printf("ERROR %s: can't copy %s\n", __func__, id->name);
BLI_assert(!"This should never happen.");
/* We need to end the FOREACH_OBJECT_FLAG iterator to prevent memory leak. */
BKE_scene_objects_iterator_end(&iter_macro);
return;
}
@@ -1876,7 +1876,7 @@ static void single_obdata_users(Main *bmain, Scene *scene, ViewLayer *view_layer
static void single_object_action_users(Scene *scene, ViewLayer *view_layer, const int flag)
{
- FOREACH_OBJECT_FLAG(scene, view_layer, flag, ob)
+ FOREACH_OBJECT_FLAG_BEGIN(scene, view_layer, flag, ob)
if (!ID_IS_LINKED(ob)) {
DEG_id_tag_update(&ob->id, OB_RECALC_DATA);
BKE_animdata_copy_id_action(&ob->id, false);
@@ -1890,7 +1890,7 @@ static void single_mat_users(Main *bmain, Scene *scene, ViewLayer *view_layer, c
Tex *tex;
int a, b;
- FOREACH_OBJECT_FLAG(scene, view_layer, flag, ob)
+ FOREACH_OBJECT_FLAG_BEGIN(scene, view_layer, flag, ob)
if (!ID_IS_LINKED(ob)) {
for (a = 1; a <= ob->totcol; a++) {
ma = give_current_material(ob, a);
@@ -2045,7 +2045,7 @@ void ED_object_single_users(Main *bmain, Scene *scene, const bool full, const bo
{
IDP_RelinkProperty(scene->id.properties);
- FOREACH_SCENE_OBJECT(scene, ob)
+ FOREACH_SCENE_OBJECT_BEGIN(scene, ob)
{
if (!ID_IS_LINKED(ob)) {
IDP_RelinkProperty(ob->id.properties);
@@ -1849,7 +1849,7 @@ static void single_obdata_users(Main *bmain, Scene *scene, ViewLayer *view_layer
printf("ERROR %s: can't copy %s\n", __func__, id->name);
BLI_assert(!"This should never happen.");
- /* We need to end the FOREACH_OBJECT_FLAG iterator to prevent memory leak. */
+ /* We need to end the FOREACH_OBJECT_FLAG_BEGIN iterator to prevent memory leak. */
BKE_scene_objects_iterator_end(&iter_macro);
return;